#---------------------------------------------------
# Glue Trigger
#---------------------------------------------------

locals {
  job_name =  var.glue_job_name != "" ? var.glue_job_name : null
  crawler_name =  var.glue_crawler_name != "" ? var.glue_crawler_name : null
  is_conditional_trigger_type = upper(var.glue_trigger_type) == "CONDITIONAL" ? true : false
}

resource "aws_glue_workflow" "glue_workflow" {
  name =  "${var.glue_trigger_name}-workflow"
  tags = var.tags
}

resource "aws_glue_trigger" "glue_trigger" {

  name = var.glue_trigger_name
  type = upper(var.glue_trigger_type)

  description   = var.glue_trigger_description
  enabled       = var.glue_trigger_enabled
  schedule      = var.glue_trigger_schedule == "" ? null : var.glue_trigger_schedule
  workflow_name = aws_glue_workflow.glue_workflow.id

  actions {
    # Both JobName or CrawlerName cannot be set together in an action
    crawler_name = local.crawler_name
    job_name     = local.job_name
  }

  #Required when trigger type is CONDITIONAL
  dynamic "predicate" {
    for_each = local.is_conditional_trigger_type ? ["true"] : []
    content {
      logical = var.predicate_logical

      dynamic "conditions" {
        iterator = conditions
        for_each = var.predicate_conditions

        content {
          job_name         = lookup(conditions.value, "job_name", null)
          state            = lookup(conditions.value, "state", null)
          crawler_name     = lookup(conditions.value, "crawl_name", null)
          crawl_state      = lookup(conditions.value, "crawl_state", null)
          logical_operator = lookup(conditions.value, "logical_operator", null)
        }
      }
    }
  }

  timeouts {
   
      create = var.create_timeout
      delete = var.delete_timeout
  }

  tags = var.tags

  lifecycle {
    create_before_destroy = true
    ignore_changes        = []
  }

  depends_on = [
    aws_glue_workflow.glue_workflow
  ]
}
